@@ -42,6 +42,9 @@ struct _AnjutaTreeComboBoxPrivate
 	GtkWidget *cell_view;
 	GtkCellArea *area;
 
+	GtkWidget *invalid_notebook;
+	GtkWidget *invalid_label;
+
 	GtkWidget *popup_window;
 	GtkWidget *scrolled_window;
 	GtkWidget *tree_view;
@@ -56,6 +59,15 @@ struct _AnjutaTreeComboBoxPrivate
 
 	gint active; 						/* Only temporary */
 	GtkTreeRowReference *active_row;	/* Current selected row */
+
+	GtkTreeModelFilterVisibleFunc valid_func;
+	gpointer valid_data;
+	GDestroyNotify valid_destroy;
+};
+
+enum {
+	INVALID_PAGE = 0,
+	VALID_PAGE = 1
 };
 
 enum {
@@ -65,6 +77,11 @@ enum {
 	LAST_SIGNAL
 };
 
+enum {
+  PROP_0,
+  PROP_MODEL
+};
+
 static guint signals[LAST_SIGNAL] = {0,};
 
 #define SCROLL_TIME  100
@@ -394,16 +411,31 @@ anjuta_tree_combo_box_set_active_path (AnjutaTreeComboBox *combo,
 	{
 		gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->tree_view)));
        	gtk_cell_view_set_displayed_row (GTK_CELL_VIEW (priv->cell_view), NULL);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->invalid_notebook), INVALID_PAGE);
 		if (!valid)	return;
     }
 	else
     {
+		GtkTreeIter iter;
+
 		priv->active_row = gtk_tree_row_reference_new (priv->model, path);
 
-        gtk_cell_view_set_displayed_row (GTK_CELL_VIEW (priv->cell_view), path);
 		gtk_tree_view_expand_to_path (GTK_TREE_VIEW (priv->tree_view), path);
 		gtk_tree_view_set_cursor (GTK_TREE_VIEW (priv->tree_view), path, NULL, FALSE);
 		gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (priv->tree_view), path, NULL, TRUE, 0.5, 0.0);
+
+		if ((priv->valid_func == NULL) ||
+		    (gtk_tree_model_get_iter (combo->priv->model, &iter, path) &&
+			priv->valid_func (combo->priv->model, &iter, priv->valid_data)))
+		{
+        	gtk_cell_view_set_displayed_row (GTK_CELL_VIEW (priv->cell_view), path);
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->invalid_notebook), VALID_PAGE);
+		}
+		else
+		{
+        	gtk_cell_view_set_displayed_row (GTK_CELL_VIEW (priv->cell_view), NULL);
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->invalid_notebook), INVALID_PAGE);
+		}
 	}
 
 	g_signal_emit (combo, signals[CHANGED], 0);
@@ -414,6 +446,22 @@ anjuta_tree_combo_box_set_active_path (AnjutaTreeComboBox *combo,
 /* Callbacks functions
  *---------------------------------------------------------------------------*/
 
+static gboolean
+anjuta_tree_can_select_node (GtkTreeSelection *selection,
+                             GtkTreeModel *model,
+                             GtkTreePath *path,
+                             gboolean path_currently_selected,
+                             gpointer data)
+{
+	AnjutaTreeComboBoxPrivate *priv = ANJUTA_TREE_COMBO_BOX (data)->priv;
+	GtkTreeIter iter;
+
+	return path_currently_selected ||
+	    (priv->valid_func == NULL) ||
+	    (gtk_tree_model_get_iter (priv->model, &iter, path) &&
+	     priv->valid_func (priv->model, &iter, priv->valid_data));
+}
+
 static void
 anjuta_tree_combo_box_auto_scroll (AnjutaTreeComboBox *combo,
                                    gint         x,
@@ -491,8 +539,6 @@ anjuta_tree_combo_box_key_press (GtkWidget   *widget,
 	{
 		GtkTreeModel *model = NULL;
 
-		anjuta_tree_combo_box_popdown (combo);
-
 		if (combo->priv->model)
 		{
 			GtkTreeSelection *sel;
@@ -503,6 +549,8 @@ anjuta_tree_combo_box_key_press (GtkWidget   *widget,
 				anjuta_tree_combo_box_set_active_iter (combo, &iter);
 		}
 
+		anjuta_tree_combo_box_popdown (combo);
+
 		return TRUE;
 	}
 
@@ -671,12 +719,18 @@ anjuta_tree_combo_box_button_released (GtkWidget      *widget,
 		return TRUE; /* clicked outside window? */
 
 	gtk_tree_model_get_iter (priv->model, &iter, path);
+
+	if (anjuta_tree_can_select_node (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->tree_view)),
+	                                 priv->model,
+	                                 path,
+	                                 FALSE,
+	                                 combo))
+	{
+		anjuta_tree_combo_box_popdown (combo);
+		anjuta_tree_combo_box_set_active_iter (combo, &iter);
+	}
 	gtk_tree_path_free (path);
 
-	anjuta_tree_combo_box_popdown (combo);
-
-	anjuta_tree_combo_box_set_active_iter (combo, &iter);
-
 	return TRUE;
 }
 
@@ -764,8 +818,6 @@ anjuta_tree_combo_box_popup_setup (AnjutaTreeComboBox *combo)
 }
 
 
-
-
 /* Public functions
  *---------------------------------------------------------------------------*/
 
@@ -857,16 +909,50 @@ anjuta_tree_combo_box_get_active_iter (AnjutaTreeComboBox *combo,
 	GtkTreePath *path;
 	gboolean valid = FALSE;
 
-	path = gtk_tree_row_reference_get_path (priv->active_row);
-	if (path)
+	if (priv->active_row != NULL)
 	{
-		valid = gtk_tree_model_get_iter (priv->model, iter, path);
-		gtk_tree_path_free (path);
+		path = gtk_tree_row_reference_get_path (priv->active_row);
+		if (path)
+		{
+			valid = gtk_tree_model_get_iter (priv->model, iter, path);
+			gtk_tree_path_free (path);
+		}
 	}
 
 	return valid;
 }
 
+void
+anjuta_tree_combo_box_set_valid_function (AnjutaTreeComboBox *combo,
+                                          GtkTreeModelFilterVisibleFunc func,
+                                          gpointer data,
+                                          GDestroyNotify destroy)
+{
+	AnjutaTreeComboBoxPrivate *priv = combo->priv;
+	GtkTreeSelection *selection;
+
+	if (priv->valid_destroy != NULL)
+	{
+		priv->valid_destroy (priv->valid_data);
+	}
+	priv->valid_func = func;
+	priv->valid_data = data;
+	priv->valid_destroy = destroy;
+
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->tree_view));
+	gtk_tree_selection_set_select_function (selection, func != NULL ? anjuta_tree_can_select_node : NULL, func != NULL ? combo : NULL, NULL);
+}
+
+void
+anjuta_tree_combo_box_set_invalid_text (AnjutaTreeComboBox *combo,
+                                        const gchar *str)
+{
+	AnjutaTreeComboBoxPrivate *priv = combo->priv;
+
+	gtk_label_set_text (GTK_LABEL (priv->invalid_label), str);
+}
+
 
 GtkWidget *
 anjuta_tree_combo_box_new (void)
@@ -931,6 +1017,11 @@ anjuta_tree_combo_box_dispose (GObject *object)
       priv->area = NULL;
     }
 
+	if (priv->valid_destroy != NULL)
+	{
+		priv->valid_destroy (priv->valid_data);
+		priv->valid_destroy = NULL;
+	}
 	anjuta_tree_combo_box_unset_model (combo);
 
 	anjuta_tree_combo_box_popup_destroy (combo);
@@ -943,6 +1034,7 @@ anjuta_tree_combo_box_init (AnjutaTreeComboBox *combo)
 {
   	AnjutaTreeComboBoxPrivate *priv;
 	GtkWidget *box, *sep, *arrow;
+	GtkWidget *image, *ibox;
 
 	priv = G_TYPE_INSTANCE_GET_PRIVATE (combo,
 	                                    ANJUTA_TYPE_TREE_COMBO_BOX,
@@ -953,6 +1045,9 @@ anjuta_tree_combo_box_init (AnjutaTreeComboBox *combo)
 	priv->active = -1;
 	priv->active_row = NULL;
 
+	priv->valid_func = NULL;
+	priv->valid_destroy = NULL;
+
 	gtk_widget_push_composite_child ();
 
 	gtk_widget_set_halign (GTK_WIDGET (combo), GTK_ALIGN_FILL);
@@ -968,11 +1063,30 @@ anjuta_tree_combo_box_init (AnjutaTreeComboBox *combo)
 	gtk_container_add (GTK_CONTAINER (combo), box);
 	gtk_widget_show (box);
 
+	priv->invalid_notebook = gtk_notebook_new ();
+	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->invalid_notebook), FALSE);
+	gtk_notebook_set_show_border (GTK_NOTEBOOK (priv->invalid_notebook), FALSE);
+	gtk_box_pack_start (GTK_BOX (box), priv->invalid_notebook, TRUE, TRUE, 0);
+
+	ibox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+	gtk_notebook_append_page (GTK_NOTEBOOK (priv->invalid_notebook), ibox, NULL);
+	gtk_widget_show (ibox);
+
+	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_SMALL_TOOLBAR);
+	gtk_box_pack_start (GTK_BOX (ibox), image, FALSE, FALSE, 0);
+	gtk_widget_show (image);
+
+	priv->invalid_label = gtk_label_new (_("<Invalid>"));
+	gtk_misc_set_alignment (GTK_MISC (priv->invalid_label), 0, 1);
+	gtk_misc_set_padding (GTK_MISC (priv->invalid_label), 3, 3);
+	gtk_box_pack_start (GTK_BOX (ibox), priv->invalid_label, TRUE, TRUE, 0);
+	gtk_widget_show (priv->invalid_label);
+
 	priv->area = gtk_cell_area_box_new ();
 	g_object_ref_sink (priv->area);
 
 	priv->cell_view = gtk_cell_view_new_with_context (priv->area, NULL);
-	gtk_box_pack_start (GTK_BOX (box), priv->cell_view, TRUE, TRUE, 0);
+	gtk_notebook_append_page (GTK_NOTEBOOK (priv->invalid_notebook), priv->cell_view, NULL);
 	gtk_widget_show (priv->cell_view);
 
 	sep = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
@@ -985,9 +1099,49 @@ anjuta_tree_combo_box_init (AnjutaTreeComboBox *combo)
 
 	gtk_widget_pop_composite_child ();
 
+	gtk_widget_show_all (GTK_WIDGET (combo));
+
 	anjuta_tree_combo_box_popup_setup (combo);
 }
 
+static void
+anjuta_tree_combo_box_set_property (GObject      *object,
+                                    guint         prop_id,
+                                    const GValue *value,
+                                    GParamSpec   *pspec)
+{
+	AnjutaTreeComboBox *combo = ANJUTA_TREE_COMBO_BOX (object);
+
+	switch (prop_id)
+	{
+    case PROP_MODEL:
+		anjuta_tree_combo_box_set_model (combo, g_value_get_object (value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+anjuta_tree_combo_box_get_property (GObject    *object,
+                                    guint       prop_id,
+                                    GValue     *value,
+                                    GParamSpec *pspec)
+{
+	AnjutaTreeComboBox *combo = ANJUTA_TREE_COMBO_BOX (object);
+
+	switch (prop_id)
+	{
+	case PROP_MODEL:
+        g_value_set_object (value, combo->priv->model);
+        break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+    }
+}
+
 static void
 anjuta_tree_combo_box_class_init (AnjutaTreeComboBoxClass * class)
 {
@@ -1000,6 +1154,9 @@ anjuta_tree_combo_box_class_init (AnjutaTreeComboBoxClass * class)
 
 	gobject_class = G_OBJECT_CLASS (class);
 	gobject_class->dispose = anjuta_tree_combo_box_dispose;
+	gobject_class->set_property = anjuta_tree_combo_box_set_property;
+	gobject_class->get_property = anjuta_tree_combo_box_get_property;
+
 
 	/* Signals */
 	signals[CHANGED] = g_signal_new ("changed",
@@ -1026,6 +1183,21 @@ anjuta_tree_combo_box_class_init (AnjutaTreeComboBoxClass * class)
 	                                               g_cclosure_marshal_VOID__VOID,
 	                                               G_TYPE_NONE, 0);
 
+	/**
+	 * AnjutaTreeCombo:model:
+	 *
+	 * The model from which the combo box takes the values shown
+	 * in the list.
+	 *
+	 */
+	g_object_class_install_property (gobject_class,
+	                                 PROP_MODEL,
+	                                 g_param_spec_object ("model",
+	                                                      _("ComboBox model"),
+	                                                      _("The model for the combo box"),
+	                                                      GTK_TYPE_TREE_MODEL,
+	                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+
 	/* Key bindings */
 	binding_set = gtk_binding_set_by_class (widget_class);
 
