@@ -1565,7 +1565,7 @@ amp_project_update_node (AnjutaProjectNode *key, AnjutaProjectNode *value, GHash
 
 			if (new_node->parent == NULL)
 			{
-				/* This is the root node, update only the children */
+				/* This is the top loaded node, update only the children */
 				node->children = new_node->children;
 			}
 			else
@@ -1624,6 +1624,14 @@ amp_project_duplicate_node (AnjutaProjectNode *old_node)
 		// the value will be overwritten with the new node empty value.
 		amp_package_node_add_token (AMP_PACKAGE_NODE (new_node), amp_package_node_get_token (AMP_PACKAGE_NODE (old_node)));
 	}
+	if (anjuta_project_node_get_node_type (old_node) == ANJUTA_PROJECT_GROUP)
+	{
+
+		amp_group_node_add_token (AMP_GROUP_NODE (new_node), amp_group_node_get_first_token (AMP_GROUP_NODE (old_node), AM_GROUP_TOKEN_CONFIGURE), AM_GROUP_TOKEN_CONFIGURE);
+		amp_group_node_add_token (AMP_GROUP_NODE (new_node), amp_group_node_get_first_token (AMP_GROUP_NODE (old_node), AM_GROUP_TOKEN_SUBDIRS), AM_GROUP_TOKEN_SUBDIRS);
+		amp_group_node_add_token (AMP_GROUP_NODE (new_node), amp_group_node_get_first_token (AMP_GROUP_NODE (old_node), AM_GROUP_TOKEN_DIST_SUBDIRS), AM_GROUP_TOKEN_DIST_SUBDIRS);
+
+	}
 	if (anjuta_project_node_parent (old_node) == NULL)
 	{
 		// FIXME: It would be better to write a duplicate function to avoid this code
@@ -2141,6 +2149,8 @@ amp_load_complete (PmJob *job)
 	}*/
 	map = amp_project_map_node (job->node, job->proxy);
 	g_object_ref (job->proxy);
+
+	job->proxy->parent = NULL;	// Mark loaded top node
 	g_hash_table_foreach (map, (GHFunc)amp_project_update_node, map);
 	//anjuta_project_node_check (job->node);
 	g_hash_table_destroy (map);
