@@ -45,6 +45,7 @@
 #include "plugin.h"
 #include "file_history.h"
 #include "search-box.h"
+#include "search-files.h"
 #include "anjuta-bookmarks.h"
 
 static IAnjutaDocument *
@@ -911,6 +912,20 @@ on_search_popup_regex_search (GtkAction *action, gpointer user_data)
 	search_box_toggle_regex (SEARCH_BOX (search_box), regex_active);
 }
 
+void 
+on_search_find_in_files (GtkAction *action, gpointer user_data)
+{
+	DocmanPlugin *plugin;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
+
+	if (!plugin->search_files)
+	{
+		plugin->search_files = G_OBJECT (search_files_new (ANJUTA_DOCMAN (plugin->docman),
+		                                                   SEARCH_BOX(plugin->search_box)));
+	}
+	search_files_present (SEARCH_FILES(plugin->search_files));
+}
+
 void
 on_editor_add_view_activate (GtkAction *action, gpointer user_data)
 {
@@ -1023,9 +1038,7 @@ void
 on_autocomplete_activate (GtkAction *action, gpointer user_data)
 {
 	IAnjutaDocument *doc;
-	DocmanPlugin *plugin;
 	doc = get_current_document (user_data);
-	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	if (doc && IANJUTA_IS_EDITOR_ASSIST(doc))
 	{
 		IAnjutaEditorAssist* assist = IANJUTA_EDITOR_ASSIST (doc);
