@@ -1083,14 +1083,13 @@ anjuta_docman_remove_document (AnjutaDocman *docman, IAnjutaDocument *doc)
 	page = anjuta_docman_get_page_for_document (docman, doc);
 	if (page)
 	{
-		gtk_container_remove (GTK_CONTAINER (docman), page->widget);
 		docman->priv->pages = g_list_remove (docman->priv->pages, (gpointer)page);
 		if (!g_list_length (docman->priv->pages))
 				g_signal_emit (G_OBJECT (docman), docman_signals[DOC_CHANGED], 0, NULL);
 		g_free (page);
 	}
+	gtk_widget_destroy(GTK_WIDGET(doc));
 	anjuta_docman_update_documents_menu(docman);
-	g_object_unref (doc);
 }
 
 void
